FormattedBytes

Struct FormattedBytes 

pub struct FormattedBytes { /* private fields */ }
A stack-allocated buffer containing the formatted byte string.

FormattedBytes calculates the formatting upon instantiation and stores the result internally. It can be cheaply converted to a &str or &[u8].

Implementations

Source

impl FormattedBytes

pub fn as_bytes(&self) -> &[u8]

Returns the formatted output as a raw byte slice. Useful for direct std::io::Write usage.

pub fn as_str(&self) -> Result<&str, Utf8Error>

Returns the formatted output as a UTF-8 string slice.

Errors

Returns a core::str::Utf8Error if the internal buffer contains invalid UTF-8 bytes. (Note: The format method only writes valid ASCII characters, so this is guaranteed to succeed in practice).